2.0.14.1 (2020-06-03)
---------------------

Fixed:

- Fixed UnicodeDecodeError on python2 for the @@rsvp.csv view. (`Issue #3393 <https://github.com/quaive/ploneintranet/issues/3393>`_)

2.0.14 (2020-05-25)
-------------------

Added:


- Added @@rsvp.csv view to download interested conference attendees in CSV format. (`Issue #3107 <https://github.com/quaive/ploneintranet/issues/3107>`_)


Changed:


- Improved support for video files and links (`Issue #3243 <https://github.com/quaive/ploneintranet/issues/3243>`_)


Fixed:


- Do not use svg generated by pdf2svg if they are bigger than 1MB (`Issue #2241 <https://github.com/quaive/ploneintranet/issues/2241>`_)
- Scroll first talk of each day into view in conference schedule (`Issue #3107 <https://github.com/quaive/ploneintranet/issues/3107>`_)
- Register (un)join a talk in the schedule when accessed via the @@promo view (`Issue #3107 <https://github.com/quaive/ploneintranet/issues/3107>`_)
- The profile edit form now behaves as intended, using an explicit Save button instead of auto-save (`Issue #3223 <https://github.com/quaive/ploneintranet/issues/3223>`_)
- Prevent a unicode error on Python2.7 (`Issue #3358 <https://github.com/quaive/ploneintranet/issues/3358>`_)
- Remove the download menu on link objects (`Issue #3362 <https://github.com/quaive/ploneintranet/issues/3362>`_)


Technical:


- Prefer the builtin unittest mock over the external mock library (`Issue #0000 <https://github.com/quaive/ploneintranet/issues/0000>`_)
- Replace deprecated assertEquals and assertNotEquals with assertEqual and assertNotEqual (`Issue #0001 <https://github.com/quaive/ploneintranet/issues/0001>`_)
- Use plone.memoize 2.1.0 which contains the code backported from ploneintranet.layout.memoize (`Issue #0002 <https://github.com/quaive/ploneintranet/issues/0002>`_)


Updated:


- Update:
  quaive.app.audit = 2.1.0
  quaive.app.classifieds = 1.0.1
  quaive.app.onlyoffice = 2.1.0
  (`Issue #0000 <https://github.com/quaive/ploneintranet/issues/0000>`)_


2.0.13 (2020-05-11)
-------------------

Added:


- Documents Portlet: Icons reflect document type (`Issue #3288 <https://github.com/quaive/ploneintranet/issues/3288>`_)


Changed:


- Todo: Changed notification email when task assigned (`Issue #3244 <https://github.com/quaive/ploneintranet/issues/3244>`_)
- Todo App: User stays in the context of app after creating task (`Issue #3245 <https://github.com/quaive/ploneintranet/issues/3245>`_)
- No tag icons are displayed in the "Edit Dashboard" view (`Issue #3276 <https://github.com/quaive/ploneintranet/issues/3276>`_)
- Tip of the day: "Read more" link is now injected (`Issue #3286 <https://github.com/quaive/ploneintranet/issues/3286>`_)
- Event portlet - Link to central event (`Issue #3307 <https://github.com/quaive/ploneintranet/issues/3307>`_)
- Only show one item (current app or workspace) in the breadcrumbs (`Issue #3341 <https://github.com/quaive/ploneintranet/issues/3341>`_)


Fixed:


- In the events promo view, hide the map when no location is given (`Issue #3107 <https://github.com/quaive/ploneintranet/issues/3107>`_)
- Update personal avatar correctly when a new image is uploaded. (`Issue #3221 <https://github.com/quaive/ploneintranet/issues/3221>`_)
- The link to the library item should not download it but link to the view (`Issue #3251 <https://github.com/quaive/ploneintranet/issues/3251>`_)
- The event tiles now show the location instead of the description. (`Issue #3253 <https://github.com/quaive/ploneintranet/issues/3253>`_)
- Fix the event editing process so that auto-save works smoothly without data loss. (`Issue #3254 <https://github.com/quaive/ploneintranet/issues/3254>`_)
- Removed the hash in front of the tags because we already have an icon there. (`Issue #3256 <https://github.com/quaive/ploneintranet/issues/3256>`_)
- Clicking on an image in the stream now opens the gallery view. If there is more than one image, only the first is shown in the stream, but all are present in the gallery view. (`Issue #3260 <https://github.com/quaive/ploneintranet/issues/3260>`_)
- Support setting both the organisation and the title of the intranet explicitly. (`Issue #3268 <https://github.com/quaive/ploneintranet/issues/3268>`_)
- Empty portraits from ldap are properly synced (`Issue #3278 <https://github.com/quaive/ploneintranet/issues/3278>`_)
- News: Parent section is now marked as current when following a direct link to a news item (`Issue #3285 <https://github.com/quaive/ploneintranet/issues/3285>`_)
- Fixed a bug where the pat-switch statement was on user instead on group items. This makes contacts app behave properly on mobile (`Issue #3310 <https://github.com/quaive/ploneintranet/issues/3310>`_)
- News app: Make retrieving the news item creator fullname more robust.
  Backport from customer project. (`Issue #3339 <https://github.com/quaive/ploneintranet/issues/3339>`_)
- Schedule modal: fix form submission (`Issue #3351 <https://github.com/quaive/ploneintranet/issues/3351>`_)


Technical:


- Support Python3.8 (`Issue #0002 <https://github.com/quaive/ploneintranet/issues/0002>`_)
- Fix log statement when syncing groups from ldap (`Issue #3271 <https://github.com/quaive/ploneintranet/issues/3271>`_)


Updated:


- Updated quaive.resources.ploneintranet to 5.0.19 containing
  * a diazo rule cleanup as we are now explicitly setting quaive_title and quaive_organisation
  * new css that fixes "message of the day" display
  * mobile support for the contacts app
  * a ton of design fixes
  * initial push support (`Issue #0000 <https://github.com/quaive/ploneintranet/issues/0000>`_)
- Updated quaive.app.absences to 1.3.0a2 (`Issue #0001 <https://github.com/quaive/ploneintranet/issues/0001>`_)
- Updated kombu to 4.6.8 to support Python3.8 (`Issue #0002 <https://github.com/quaive/ploneintranet/issues/0002>`_)
- Updated quaive.app.milestones to 2.0.4 (`Issue #0003 <https://github.com/quaive/ploneintranet/issues/0003>`_)


2.0.12 (2020-04-20)
-------------------

Fixed:


- When the remote admin is changed update the catalog to make the content searchable by the remote admin user or group (`Issue #2828 <https://github.com/quaive/ploneintranet/issues/2828>`_)
- Recently the search icon appeared at every level but clicking on it had not effect (`Issue #3102 <https://github.com/quaive/ploneintranet/issues/3102>`_)
- Show the owner among the group administrators in the group view (`Issue #3180 <https://github.com/quaive/ploneintranet/issues/3180>`_)
- Remove the broken links to a not existent help in the calendar view (`Issue #3210 <https://github.com/quaive/ploneintranet/issues/3210>`_)
- Avatar upload was broken and consequently the default avatar was shown (`Issue #3213 <https://github.com/quaive/ploneintranet/issues/3213>`_)
- Library now renders all pages instead of only one (`Issue #3215 <https://github.com/quaive/ploneintranet/issues/3215>`_)
- Removed a surplus div in the library view (`Issue #3225 <https://github.com/quaive/ploneintranet/issues/3225>`_)
- Search page now has autofocus (`Issue #3228 <https://github.com/quaive/ploneintranet/issues/3228>`_)
- Do not show duplicate events in the events portlet (`Issue #3230 <https://github.com/quaive/ploneintranet/issues/3230>`_)
- Viewing the library by tag was throwing an error on Python3 (`Issue #3236 <https://github.com/quaive/ploneintranet/issues/3236>`_)


Technical:


- Remove obsolete code (`Issue #3210 <https://github.com/quaive/ploneintranet/issues/3210>`_)
- Update the pas graph after user/grup sync (`Issue #3232 <https://github.com/quaive/ploneintranet/issues/3232>`_)
- Simplify implementation of ``in_workspace`` utility method.
  Fix some code formatting leftovers. (`Issue #3234 <https://github.com/quaive/ploneintranet/issues/3234>`_)
- Fix empty profile titles in portal setup in ZMI. (`Issue #3238 <https://github.com/quaive/ploneintranet/issues/3238>`_)


Updated:


- Update quaive.resources.ploneintranet to 5.0.9. (`Issue #3261 <https://github.com/quaive/ploneintranet/issues/3261>`_)


2.0.11 (2020-04-04)
-------------------

Added:


- Conference support, intermediate release: voting on proposed talks. This work is still in progress. (`Issue #3107 <https://github.com/quaive/ploneintranet/issues/3107>`_)


Fixed:


- Fixed the cart action "Download" (`Issue #3034 <https://github.com/quaive/ploneintranet/issues/3034>`_)
- Fixed a broken link that prevented opening the tasks sidebar when browsing to some object inside a folder inside a workspace (`Issue #3196 <https://github.com/quaive/ploneintranet/issues/3196>`_)
- Fixed an issue where the user could potentially remove an image or a file by just clicking "Save" (`Issue #3198 <https://github.com/quaive/ploneintranet/issues/3198>`_)


Technical:


- The view @@pi-refresh-compilations now also refreshes the
  timestamp for the ploneintranet-workspace-styles bundle (`Issue #1550 <https://github.com/quaive/ploneintranet/issues/1550>`_)


2.0.10 (2020-03-30)
-------------------

Added:


- Added "About this calendar" entry to the central calendar context menu. (`Issue #3181 <https://github.com/quaive/ploneintranet/issues/3181>`_)


Changed:


- When documents are sent using the bulk action in the workspace sidebar, the user who sends them is added in the CC field.
  It is now also possible to pick a group among the recipients. The mail will be sent to all the group members. (`Issue #3175 <https://github.com/quaive/ploneintranet/issues/3175>`_)
- Show group administrators in group view. (`Issue #3179 <https://github.com/quaive/ploneintranet/issues/3179>`_)


Fixed:


- Allow redactor to upload images again (`Issue #3166 <https://github.com/quaive/ploneintranet/issues/3166>`_)
- Allow certain items in the Library of an upgraded installation (Plone5.2) to be edited again. (`Issue #3172 <https://github.com/quaive/ploneintranet/issues/3172>`_)
- It is now possible to attach images when using the bulk email feature (`Issue #3175 <https://github.com/quaive/ploneintranet/issues/3175>`_)
- Text editor/Redactor 3:
      - Fix upload of multiple images.
      - Show source button.
      - Fix checkboxes not displayed correctly.
      - Tables not 100% wide.
      - Upgrade to Redactor 3.3.4. (`Issue #3177 <https://github.com/quaive/ploneintranet/issues/3177>`_)
- Mark current active document in the sidebar navigation also on initial load. (`Issue #3178 <https://github.com/quaive/ploneintranet/issues/3178>`_)


Technical:


- Bump suite metadate version to 0021 and move legacy removal handler to to_0021. (`Issue #3158 <https://github.com/quaive/ploneintranet/issues/3158>`_)
- Workspace color can be overriden by providing a ws_type property in the workspace view (`Issue #3169 <https://github.com/quaive/ploneintranet/issues/3169>`_)
- Fix a Python3 comparison error when checking for the existence of previews.
  Fix a Python3 migration error that casted search results into a list. (`Issue #3188 <https://github.com/quaive/ploneintranet/issues/3188>`_)


Updated:


- Updated Products.CMFNotifications to 3.0.0a2
  Updated collective.auditlog to 2.0.0a2
  Updated quaive.app.taxonomy to 1.3.2 (`Issue #3152 <https://github.com/quaive/ploneintranet/issues/3152>`_)
- Update quaive.resources.ploneintranet to 5.0.8. (`Issue #3177 <https://github.com/quaive/ploneintranet/issues/3177>`_)


2.0.9 (2020-03-17)
------------------

Added:


- Added the possibility to have video conference integration using a service like Jitsi or Google Hangout (`Issue #2038 <https://github.com/quaive/ploneintranet/issues/2038>`_)
- Mark the current document in the documents sidebar in workspaces as active. (`Issue #3157 <https://github.com/quaive/ploneintranet/issues/3157>`_)


Fixed:


- Previews are properly generated after a document is modified with ONLYOFFICE (`Issue #3161 <https://github.com/quaive/ploneintranet/issues/3161>`_)


Updated:


- Upgrade quaive.app.legal to 1.1.1 (`Issue #0000 <https://github.com/quaive/ploneintranet/issues/0000>`_)
- Upgrade quaive.resources.ploneintranet to 5.0.6 (`Issue #1889 <https://github.com/quaive/ploneintranet/issues/1889>`_)


2.0.8 (2020-03-12)
------------------

Added:


- Events: Added new fields for the event content type and a new @@promo view (`Issue #3044 <https://github.com/quaive/ploneintranet/issues/3044>`_)
- Support Plone5.2, bith using Python 2.7 and Python 3.7

Changed:


- News: Do not show the description if it was auto-generated from the body text, as for syndicated news items. (`Issue #3143 <https://github.com/quaive/ploneintranet/issues/3143>`_)
- Search: Updated search result markup to newer and more flexible style (`Issue #3130 <https://github.com/quaive/ploneintranet/issues/3130>`_)


Fixed:


- Fixed search error when user can't view a result's parent (`Issue #1885 <https://github.com/quaive/ploneintranet/issues/1885>`_)
- Fix upgrade step to make events versionable (`Issue #2108 <https://github.com/quaive/ploneintranet/issues/2108>`_)
- When creating or updating content with rich text fields, do not clean up html for mime types other than text/html and the like (`Issue #3039 <https://github.com/quaive/ploneintranet/issues/3039>`_)
- Remove metadata box from videos. Remove "Open in external editor" and "Open in only office" for audio/video files. (`Issue #3063 <https://github.com/quaive/ploneintranet/issues/3063>`_)
- Fix redactor editor toolbar not being shown. Fix usage of redactor 3 configuration parameters. (`Issue #3091 <https://github.com/quaive/ploneintranet/issues/3091>`_)
- Fixed a glitch in the Library tag view. (`Issue #3093 <https://github.com/quaive/ploneintranet/issues/3093>`_)
- Mailed files now have the proper filename with extension instead of the title of the document. This is needed so that Outlook can properly open the files. (`Issue #3095 <https://github.com/quaive/ploneintranet/issues/3095>`_)
- News syndication: expect a valid Atom feed (`Issue #3103 <https://github.com/quaive/ploneintranet/issues/3103>`_)
- News Publisher: the create and edit views for news sections and syndicated sections have been updated. The create form for both now contains all fields that can also be set in the edit form. The fields are now in their logical order, according to prototype. When a syndicated section is edited, the URL can now be changed as well. (`Issue #3101 <https://github.com/quaive/ploneintranet/issues/3101>`_)
- Fix icons for link objects in the Library (`Issue #3109 <https://github.com/quaive/ploneintranet/issues/3109>`_)
- Limit news in expanded mode to 10 items. Speed improvements. (`Issue #3112 <https://github.com/quaive/ploneintranet/issues/3112>`_)
- Limit events I am invited to to 5 on the dashboard (`Issue #3114 <https://github.com/quaive/ploneintranet/issues/3114>`_)
- The dashboard can handle custom tile URLS with non ASCII characters in Python2 (`Issue #3122 <https://github.com/quaive/ploneintranet/issues/3122>`_)
- updated the admin tool to gain the magnifying glass for search (`Issue #3123 <https://github.com/quaive/ploneintranet/issues/3123>`_)
- Fix error with parsing CSS when creating notification mails. (`Issue #3140 <https://github.com/quaive/ploneintranet/issues/3140>`_)
- Fix some usability glitches in the News App (`Issue #3099 <https://github.com/quaive/ploneintranet/issues/3099>`_):

  - When viewing a News Section, only show the main <h1> heading if the section comes from the "other" dropdown. If it is a section that is always visible, we already see which section we are in via the highlighted pill
  - Make sure the "current" class also is applied to the "other" dropdown for the News Section, where applicable
  - Fix injection target on the magazine view: when a news item is clicked, only inject the magazine content, so that the subnavigation that shows the current section stays valid
  - Add missing "scroll to top" on news view, so that when a news item is clicked from the magazine view, we scroll to the top correctly
  - The "News from my group" smart section now only shows public and not expired news


Technical:


- Added quaive.app.classifieds 1.0.0 (`Issue #3150 <https://github.com/quaive/ploneintranet/issues/3150>`_)
- Use IntegrationTestCase for performance reasons (`Issue #3104 <https://github.com/quaive/ploneintranet/issues/3104>`_)
- Speed up unit tests
- Remove collective documentviewer and fix setup.py to not pull in unneeded packages. (`Issue #2868 <https://github.com/quaive/ploneintranet/issues/2868>`_)
- Rename the package ploneintranet.async to ploneintranet.asynctasks.
- Prepare for Plone 5.2
- Remove the dependency from loremipsum
- Update URLs to match the new paths from quaive.resources.ploneintranet
- Fix a javascript console error (`Issue #3054 <https://github.com/quaive/ploneintranet/issues/3054>`_)
- Fix upgrade step 20 for 5.2. (`Issue #3127 <https://github.com/quaive/ploneintranet/issues/3127>`_)
- Add ``min_plone52`` property and ``min_plone_version`` method helpers to the ``@@proto`` view. (`Issue #3049 <https://github.com/quaive/ploneintranet/issues/3049>`_)
- Upgrade step to fix the grouping storage after the switch to Python3. Fix logging to work in Python 2 and Python3 (`Issue #3061 <https://github.com/quaive/ploneintranet/issues/3061>`_)
- Allow "success" status messages to be suppressed in Add and Edit views that subclass our base views. (`Issue #3068 <https://github.com/quaive/ploneintranet/issues/3068>`_)
- Make it possible to filter out certain content (which implements the interface INotShownInBookmarkOverview) from the general overview of bookmarks. (`Issue #3074 <https://github.com/quaive/ploneintranet/issues/3074>`_)
- It is now possible to mark content items with the interface ISimplifiedCommentTrail, which has the effect that no status updates from this content will appear in the general activity stream, and the comment trail on the content item itself will be displayed without   the initial status update (from the "Created" subscriber). (`Issue #3081 <https://github.com/quaive/ploneintranet/issues/3081>`_)
- When installing ploneintranet test content, do not try to send out todo mail notifications which would fail anyways due to browser layers not present. (`Issue #3139 <https://github.com/quaive/ploneintranet/issues/3139>`_)


Updated:


- New pins:

  - collective.auditlog = 2.0.0a1
  - collective.dexteritytextindexer = 2.4.0
  - collective.mustread = 2.0.0
  - collective.workspace = 3.0b1
  - dexterity.membrane = 3.0.0a1
  - htmllaundry = 2.2
  - quaive.app.absences = 1.3.0a1
  - quaive.app.audit = 2.0.0
  - quaive.app.legal = 1.1.0
  - quaive.app.milestones = 2.0.3
  - quaive.app.onlyoffice = 2.0.0
  - quaive.resources.ploneintranet = 5.0.2
  - scorched = 0.13.0
  - setuptools = 42.0.2
  - slc.outdated = 1.3.1
  - slc.zopescript = 1.1.1
  - StoneageHTML = 1.0.0
  - zc.buildout = 2.13.2


2.0.7 (2019-12-12)
------------------

Fixed:

- Fix bug in pas_graph where users with a login name not equal to their userid would encounter 302 Unauthorized responses. (`Issue #3013 <https://github.com/quaive/ploneintranet/issues/3013>`_)


Technical:


- Remove unused and unmaintained experimental pagerank feature. (`Issue #3007 <https://github.com/quaive/ploneintranet/issues/3007>`_)


2.0.6 (2019-12-09)
------------------

Added:


- @@cron maintenance view enables passwordless automated maintenance in a secure way. (`Issue #2993 <https://github.com/quaive/ploneintranet/issues/2993>`_)
  This view is optional, to enable it add it to your buildout::

    [instance-cron]
    zcml =
        ploneintranet
        ploneintranet.utils.cron


Changed:


- Do not show the placeholder image for full-width news items without an image in a multi-column layout. (`Issue #2987 <https://github.com/quaive/ploneintranet/issues/2987>`_)


Fixed:


- Fix @@sync-users by working around SIZELIMIT_EXCEEDED when enumerating users. (`Issue #2994 <https://github.com/quaive/ploneintranet/issues/2994>`_)


Technical:


- Don't return empty portlets if there is a whitespace line in the registry record. This solves the "jumpy portlets" issue. (`Issue #0000 <https://github.com/quaive/ploneintranet/issues/0000>`_)


2.0.5 (2019-11-30)
------------------

Changed:


- Add a skeleton screen for the dashboard to make it less flashy when injection completes (`Issue #2978 <https://github.com/quaive/ploneintranet/issues/2978>`_)


Fixed:


- Remove duplicate rendering of newly created comment, when expanding older comments. (`Issue #2821 <https://github.com/quaive/ploneintranet/issues/2821>`_)
- Fix spacing issue in activity stream caused by improper markup. (`Issue #2822 <https://github.com/quaive/ploneintranet/issues/2822>`_)
- Also display feeds in the news publisher sidebar (`Issue #2956 <https://github.com/quaive/ploneintranet/issues/2956>`_)
- Clicking links to workspace documents in the activity stream properly updates the browser URL (`Issue #2962 <https://github.com/quaive/ploneintranet/issues/2962>`_)
- Clean up post page template and relevant code (`Issue #2986 <https://github.com/quaive/ploneintranet/issues/2986>`_)
- Fix the persistence of the previews generated for the activity stream post attachments (`Issue #2988 <https://github.com/quaive/ploneintranet/issues/2988>`_)


Technical:


- Automate required migration/installation step to initialize pas graph. (`Issue #2967 <https://github.com/quaive/ploneintranet/issues/2967>`_)
- Cleanup test layer confusion around solr, make suite fixture extensible. (`Issue #2970 <https://github.com/quaive/ploneintranet/issues/2970>`_)
- Don't error out on ploneintranet.news:to_0013 migration if `maintainer_group` is not set. (`Issue #2973 <https://github.com/quaive/ploneintranet/issues/2973>`_)
- The reference LDAP installation for development purposes now needs to be configured manually. Remove no longer working (un)install profiles, update documentation. (`Issue #2981 <https://github.com/quaive/ploneintranet/issues/2981>`_)


2.0.4 (2019-11-20)
------------------

Fixed:


- Fix the remote admin role assignment (now he can also upload new file versions) (`Issue #2828 <https://github.com/quaive/ploneintranet/issues/2828>`_)
- Fixed an issue where the news portlet could not span two columns (`Issue #2946 <https://github.com/quaive/ploneintranet/issues/2946>`_)
- A custom permission is used to protect the publisher view (`Issue #2956 <https://github.com/quaive/ploneintranet/issues/2956>`_)
- Central Calendars: Don't ask maintainers to accept an event if a Manager submitted it.
  It is automatically accepted in this case. (`Issue #2960 <https://github.com/quaive/ploneintranet/issues/2960>`_)


Technical:


- Remove the unittest2 requirement (`Issue #2554 <https://github.com/quaive/ploneintranet/issues/2554>`_)
- Fix relation catalog by aliasing missing grok interface (`Issue #2910 <https://github.com/quaive/ploneintranet/issues/2910>`_)


Updated:


- quaive.resources.ploneintranet has been updated to version 4.1.3 to include the kkv theme and remove the unittest2 dependency (`Issue #2943 <https://github.com/quaive/ploneintranet/issues/2943>`_)
- Upgrade quaive.app.legal to 1.0.1 (`Issue #2797 <https://github.com/quaive/ploneintranet/issues/2797>`_)


2.0.3 (2019-10-17)
------------------

Added:


- Show a placeholder image for news items without an image in news overviews. (`Issue #2891 <https://github.com/quaive/ploneintranet/issues/2891>`_)
- Allow playback of audio and video files in workspaces. (`Issue #2898 <https://github.com/quaive/ploneintranet/issues/2898>`_)


Fixed:


- Fixed an error that prevented that a group could be added to a workspace in certain cases. (`Issue #2899 <https://github.com/quaive/ploneintranet/issues/2899>`_)
- In the news magazine only fetch a limited amount of news from the feeds (`Issue #2901 <https://github.com/quaive/ploneintranet/issues/2901>`_)
- Update the security settings after changing the workspace placeful workflow policy (`Issue #2905 <https://github.com/quaive/ploneintranet/issues/2905>`_)


Technical:


- Do not use the same interface for marker and provides in behavior registrations. (`Issue #2903 <https://github.com/quaive/ploneintranet/issues/2903>`_)
- Plone 5.2 fixes:
  - Remove implicit Grok dependency by using plone.supermodel, plone.supermodel.directives and plone.autoform.directives instead plone.directives.
  - Also: use @provider(IFormFieldProvider) instead alsoProvides for better readable code.
  - Remove traces of archetypes (`Issue #2908 <https://github.com/quaive/ploneintranet/issues/2908>`_)
- For the developing profile ("Suite: Create Testing Content"), add email_from_address and email_from_name to be able to send out mails to PrintingMailHost when developing/debugging the site. (`Issue #2916 <https://github.com/quaive/ploneintranet/issues/2916>`_)


Updated:


- Upgrade to Plone 5.1.6 (`Issue #2864 <https://github.com/quaive/ploneintranet/issues/2864>`_)
- Updated quaive.app.onlyoffice to version 1.6.1 (`Issue #2909 <https://github.com/quaive/ploneintranet/issues/2909>`_)


2.0.2 (2019-10-07)
------------------

Added:


- FLOW-726 - Option to show activity stream on workspace landing page. (`Issue
  #2883 <https://github.com/quaive/ploneintranet/issues/2883>`_)


Changed:


- The document portlet does not display anymore objects whose effective date is
  in the future (`Issue #2884
  <https://github.com/quaive/ploneintranet/issues/2884>`_)


Fixed:


- Return the proper status code when unauthorized or forbidden so that the
  frontend can handle it. This solves the problem of the eternal spinner when
  the user got logged out by a timeout. (`Issue #2894
  <https://github.com/quaive/ploneintranet/issues/2894>`_)
- Fixed the pdf generation for documents with a lead image (`Issue #2749
  <https://github.com/quaive/ploneintranet/issues/2749>`_)
- Password reset form is now properly styled. (`Issue #2876
  <https://github.com/quaive/ploneintranet/issues/2876>`_)


Technical:


- Adopt the black code style for ploneintranet code (`Issue #2549
  <https://github.com/quaive/ploneintranet/issues/2549>`_)
- Fix unused imports. Fix deprecated import location. Do not use obsolete AT
  content types for testing. (`Issue #2554
  <https://github.com/quaive/ploneintranet/issues/2554>`_)


Updated:


- Upgrade quaive.resources.ploneintranet to 4.1.2 (`Issue #1889
  <https://github.com/quaive/ploneintranet/issues/1889>`_)


2.0.1 (2019-10-01)
------------------

Changed:


- Improve the pop up used to mention users in workspace posts or comments.
  Speed up searching users in the workspace mention panel. Also limit the
  results to the actual members or guests. (`Issue #2832
  <https://github.com/quaive/ploneintranet/issues/2832>`_)


Fixed:


- Workspace remote admin: remove division_role_provider. This is replaced by
  the remote admin functionality. (`Issue #2827
  <https://github.com/quaive/ploneintranet/issues/2827>`_)
- Fix describe permissions message in workspace settings members tab. (`Issue
  #2859 <https://github.com/quaive/ploneintranet/issues/2859>`_)
- Groups containing unicode characters were not displayed in the workspace
  member sidebar (`Issue #2861
  <https://github.com/quaive/ploneintranet/issues/2861>`_)
- This is a follow up to #2155. Link objects in the library should have a link
  icon and folders in the document view should have the folder icon. (`Issue
  #2865 <https://github.com/quaive/ploneintranet/issues/2865>`_)


Technical:


- Remove stale files. (`Issue #2872
  <https://github.com/quaive/ploneintranet/issues/2872>`_)


2.0.0 (2019-09-16)
------------------

Added:

- Added user/group synchronisation status page. (`Issue #2802 <https://github.com/quaive/ploneintranet/issues/2802>`_)
- When viewing a news item, a link to the edit form is now available to users who have the permission to edit that news article. (`Issue #2805 <https://github.com/quaive/ploneintranet/issues/2805>`_)
- App tiles can now have the same icons as milestones can have. (`Issue #2806 <https://github.com/quaive/ploneintranet/issues/2806>`_)
- Add a Remote Admin field to workspaces.
  This allows a user to be selected as an admin for a workspace as an alternative to propagating the roles of members of a Division to workspaces which belong to that Division. (`Issue #2827 <https://github.com/quaive/ploneintranet/issues/2827>`_)
- Add @@workspace-membership-report.xls: a report on workspace members and roles (`Issue #2838 <https://github.com/quaive/ploneintranet/issues/2838>`_)
- More pronounced display of fact that permissions apply to all intranet users. (`Issue #2841 <https://github.com/quaive/ploneintranet/issues/2841>`_)
- Configure session cookies on portal setup (`Issue #2846 <https://github.com/quaive/ploneintranet/issues/2846>`_)
- Added the possibility to configure the private workspace creation through the registry.
  If the `ploneintranet.workspace.hide_private_nonmember_workspaces` registry record is set to false, newly created private workspaces will not be visible for non members and they will not be able to request access. (`Issue #2853 <https://github.com/quaive/ploneintranet/issues/2853>`_)


Changed:

- The filter option "Only my workspaces" in the workspace overview is persisted (`Issue #2855 <https://github.com/quaive/ploneintranet/issues/2855>`_)


Fixed:

- Fix avatar in userprofile base view and info pages when no portrait is present (`Issue #2773 <https://github.com/quaive/ploneintranet/issues/2773>`_)
- It is now possible to set a group as a member to a workspace that happens to have the same ID as that workspace. (`Issue #2789 <https://github.com/quaive/ploneintranet/issues/2789>`_)
- Fixed a bug where saving a file without uploading a new file could delete the original file (`Issue #2817 <https://github.com/quaive/ploneintranet/issues/2817>`_)
- Upgrade slc.mailrouter to fallback to "To" address if "X-Original-To" is missing (`Issue #2825 <https://github.com/quaive/ploneintranet/issues/2825>`_)
- The group folder review state is fixed after the default workflow is modified (`Issue #2829 <https://github.com/quaive/ploneintranet/issues/2829>`_)
- Improve the mention popup speed (`Issue #2832 <https://github.com/quaive/ploneintranet/issues/2832>`_)
- Fix mailrouter UnicodeDecodeError (`Issue #2836 <https://github.com/quaive/ploneintranet/issues/2836>`_)
- pas_view: handle unicode principal names (`Issue #2844 <https://github.com/quaive/ploneintranet/issues/2844>`_)
- Contact form is now properly styled. (`Issue #2848 <https://github.com/quaive/ploneintranet/issues/2848>`_)


Technical:

- Moved an upgrade step to be sure users with the Editor roles have the Modify portal content permission on groups.
  (`Issue #2851 <https://github.com/quaive/ploneintranet/issues/2851>`_)
- Fixed an issue where removal of users from a workspace in safari was throwing an error
  This is the same problem that was already addressed in #2799 for adding users.
  When a submit button also carries name/value attributes, safari is duplicating the variable in the request. Plone in turn converts duplicate variable names in the request into a list in python and thus the check for a keyword (add or remove) fails. (`Issue #0000 <https://github.com/quaive/ploneintranet/issues/0000>`_)


Updated:

- Upgrade quaive.resources.ploneintranet to 4.1.0 (`Issue #1889 <https://github.com/quaive/ploneintranet/issues/1889>`_)


2.0.0b3 (2019-08-05)
--------------------

Fixed:


- Fixed the message displayed to the user when objects could not be removed from the trash (`Issue #2769 <https://github.com/quaive/ploneintranet/issues/2769>`_)


Technical:


- Return proper json instead of empty string in case of NOOP. This prevents an error when data.results.length is undefined while it should be 0. (`Issue #0000 <https://github.com/quaive/ploneintranet/issues/0000>`_)
- Cleanup markup so that a submit field is not abused to carry input field values. This prevents a bug in safari where the user batch add function carries two "add" keywords and thus the action fails with the message "Unknown function" (`Issue #0001 <https://github.com/quaive/ploneintranet/issues/0001>`_)
- Added a pin for the newly released quaive.app.legal 0.9.0 (`Issue #2796 <https://github.com/quaive/ploneintranet/issues/2796>`_)


Updated:


- Upgrade quaive.resources.ploneintranet to 4.0.1 (`Issue #1889 <https://github.com/quaive/ploneintranet/issues/1889>`_)


2.0.0b2 (2019-07-22)
--------------------

Changed:


- Emails are now sent out when todos are changed or assigned. (`Issue
  #1530 <https://github.com/quaive/ploneintranet/issues/1530>`_)
- The document title is now editable when expanding the metadata bar. (`Issue
  #2753 <https://github.com/quaive/ploneintranet/issues/2753>`_)
- The bulk actions keep the same folder open in the sidebar and don't switch to
  the workspace root. (`Issue #2766
  <https://github.com/quaive/ploneintranet/issues/2766>`_)
- Empyt Trash: Better error handling. (`Issue #2768
  <https://github.com/quaive/ploneintranet/issues/2768>`_)
- Because of growing restrictions regarding the use of iframes, Link items in
  workspaces are no longer displayed inside an iframe. Instead, the option to
  open the link is shown to the user.
  (`Issue #2731
  <https://github.com/quaive/ploneintranet/issues/2731>`_)


Fixed:


- Central Calendars: Owner of an event in a "Publish" workspace cannot accept
  it as shared to arbitrary central calendars any more. (`Issue #2106
  <https://github.com/quaive/ploneintranet/issues/2106>`_)
- Solved a problem where some PDF files would not show their previews. (`Issue
  #2747 <https://github.com/quaive/ploneintranet/issues/2747>`_)
- Fixed an issue that prevented the upload of images to news items or rich
  documents. (`Issue #2760
  <https://github.com/quaive/ploneintranet/issues/2760>`_)
- Fixed an issue that prevents sharing events to central calendars on some
  systems. (`Issue #2764
  <https://github.com/quaive/ploneintranet/issues/2764>`_)
- The time shown in the notifications is now local time. (`Issue #2771
  <https://github.com/quaive/ploneintranet/issues/2771>`_)
- Removed "Confirming User Action" message when editing library documents.
  (`Issue #2779 <https://github.com/quaive/ploneintranet/issues/2779>`_)
- Workspace members: Fixed group search for non-ASCII characters. (`Issue #2781
  <https://github.com/quaive/ploneintranet/issues/2781>`_)
- Central Calendar titles can now contain non-ASCII characters. (`Issue #2784
  <https://github.com/quaive/ploneintranet/issues/2784>`_)
- Fixed "Confirming User Action" message when viewing the activity stream after
  creating an item. (`Issue #2793
  <https://github.com/quaive/ploneintranet/issues/2793>`_)


Technical:


- Cleanup that removes some obsolete internal data. SearchableText
  reindex annotations were never cleaned up and are now obsolete. (`Issue
  #2648 <https://github.com/quaive/ploneintranet/issues/2648>`_)
- Allow calling of the document_view template standalone if all I am interested
  is the document body. Fail silently if there is no tabs or division. Updated
  the markup to match latest theme. Also send task notifications on state
  change. This was missed in the notifications PR (`Issue #0000
  <https://github.com/quaive/ploneintranet/issues/0000>`_)
- There is now infrastucture code that allows us to send emails which are
  translated and consist of an html and a text part. (`Issue #1449
  <https://github.com/quaive/ploneintranet/issues/1449>`_)
- Provide an adapter for slc.mailrouter that efficiently fetch a user once the
  email is known (`Issue #2742
  <https://github.com/quaive/ploneintranet/issues/2742>`_)
- Add a deferred import for ploneintranet.news.content.INewsSectionContainer,
  some DBs still persist it (`Issue #2762
  <https://github.com/quaive/ploneintranet/issues/2762>`_)


Updated:


- Upgrade quaive.resources.ploneintranet to 4.0.0 (`Issue #1889
  <https://github.com/quaive/ploneintranet/issues/1889>`_)
- Update plone.app.versioningbehavior to 1.3.8 (`Issue #2666
  <https://github.com/quaive/ploneintranet/issues/2666>`_)
- Upgrade slc.mailrouter to version 2.1.0 (`Issue #2742
  <https://github.com/quaive/ploneintranet/issues/2742>`_)


2.0.0b1 (2019-06-06)
--------------------

Changed:


- Use custom PAS plugins for Quaive (`Issue #2078
  <https://github.com/quaive/ploneintranet/issues/2078>`_)
- The ”My Documents” tile on the dashboard now only shows published items.
  (`Issue #2689 <https://github.com/quaive/ploneintranet/issues/2689>`_)
- Central Calendars: Existing calendars are visible to the "Internal Users"
  group (instead of "Logged-In Users"). (`Issue #2699
  <https://github.com/quaive/ploneintranet/issues/2699>`_)


Fixed:


- Improved the Solr maintenance view (used by site adminstrators), so that it
  can be used with multiple sites. (`Issue #2247
  <https://github.com/quaive/ploneintranet/issues/2247>`_)
- It is possible again to close Tasks from the dashboard. (`Issue #2698
  <https://github.com/quaive/ploneintranet/issues/2698>`_)
- Central Calendars: A calendar owner can now accept/decline shared events.
  (`Issue #2702 <https://github.com/quaive/ploneintranet/issues/2702>`_)
- We can now generate previews from certain invalid PDF documents. If creating
  a preview is still not possible, we show a better feedback message about it.
  (`Issue #2703 <https://github.com/quaive/ploneintranet/issues/2703>`_)
- Library: a problem was fixed where some files would have two download links.
  (`Issue #2705 <https://github.com/quaive/ploneintranet/issues/2705>`_)
- A downloadable PDF version of a document in the library is now automatically
  updated when the document was edited. (`Issue #2711
  <https://github.com/quaive/ploneintranet/issues/2711>`_)
- Images can be attached again to comments (`Issue #2712
  <https://github.com/quaive/ploneintranet/issues/2712>`_)
- Central Calendars: The form to accept an ivitation to a calendar is only
  visible if you are allowed to use it. (`Issue #2725
  <https://github.com/quaive/ploneintranet/issues/2725>`_)
- Danish translation were improved. (`Issue #2728
  <https://github.com/quaive/ploneintranet/issues/2728>`_)
- Change how Email attachments are handled so that GMX accepts them. (`Issue
  #2735 <https://github.com/quaive/ploneintranet/issues/2735>`_)
- Fix a problem where opening a superspace would lead to overlapping workspace
  tiles (`Issue #2737 <https://github.com/quaive/ploneintranet/issues/2737>`_)


Technical:


- Upgrade to quaive.app.onlyoffice 1.6.0, upgrade to quaive.app.milestones =
  2.0.2 (`Issue #0000 <https://github.com/quaive/ploneintranet/issues/0000>`_)
- Faster whitelisting and blacklisting of the status update UIDs (`Issue #1158
  <https://github.com/quaive/ploneintranet/issues/1158>`_)
- Add missing registry record that allows to toggle commenting on News (`Issue
  #1812 <https://github.com/quaive/ploneintranet/issues/1812>`_)
- Remove any trace of plone.app.referenceablebehavior from our default
  installation. (`Issue #2141
  <https://github.com/quaive/ploneintranet/issues/2141>`_)
- Do not install obsolete registry record ploneintranet.docconv.pdf2svg.options
  (`Issue #2648 <https://github.com/quaive/ploneintranet/issues/2648>`_)
- Reindex the object after the upgrade step (`Issue #2652
  <https://github.com/quaive/ploneintranet/issues/2652>`_)
- Remove unneeded initialization of plone.app.discussion (`Issue #2721
  <https://github.com/quaive/ploneintranet/issues/2721>`_)
- Added an email index to the membrane catalog (`Issue #2733
  <https://github.com/quaive/ploneintranet/issues/2733>`_)


Updated:


- Upgrade quaive.resources.ploneintranet to 3.0.4.1 (`Issue #2737
  <https://github.com/quaive/ploneintranet/issues/2737>`_)
- Updated quaive.app.absences to 1.2.0 (`Issue #2743
  <https://github.com/quaive/ploneintranet/issues/2743>`_)


2.0.0a5 (2019-05-27)
--------------------

Added:


- Central Calendars: The visibility can now be configured. (`Issue #2106
  <https://github.com/quaive/ploneintranet/issues/2106>`_)
- There is now the profile image in front of the initiator field on the task view.
  (`Issue #2597 <https://github.com/quaive/ploneintranet/issues/2597>`_)


Changed:


- Radically improved document previews. Generation is twice as quick, download size is
  down to half and the preview images are sharp and crisp on any resolution, improving readability.
- The indexing of content has been rewritten from scratch to be much more efficient so
  that there should be nearly no conflicts anymore. This prevents duplications in the sidebar.
  (`Issue #2648 <https://github.com/quaive/ploneintranet/issues/2648>`_)
- Uploading files through drag and drop has been made more efficient. (`Issue #1079
  <https://github.com/quaive/ploneintranet/issues/1079>`_)
- Central Calendars: Permissions now work more like the news app.
  Calendar creation is not open to everyone by default any more. (`Issue #2106
  <https://github.com/quaive/ploneintranet/issues/2106>`_)
- Superspaces are made simpler which speeds up the overall system performance (`Issue
  #2652 <https://github.com/quaive/ploneintranet/issues/2652>`_)
- Bookmarked workspaces on the dashboard are now sorted by modification date (`Issue #2690
  <https://github.com/quaive/ploneintranet/issues/2690>`_)
- Better support for decentralised administration: Division admins can manage all the
  workspaces that belong to the division (`Issue #2691
  <https://github.com/quaive/ploneintranet/issues/2691>`_)


Fixed:


- Previews of files attached to the activity stream now look nicer. (`Issue
  #2679 <https://github.com/quaive/ploneintranet/issues/2679>`_)
- Fixed an issue where a special character in the title of one file leads to an error when
  trying to change the metadata for many objects. (`Issue #2687
  <https://github.com/quaive/ploneintranet/issues/2687>`_)
- Userprofile: The workspace count now excludes archived workspaces and thus is
  consistent with the number of the displayed workspaces. (`Issue #2696
  <https://github.com/quaive/ploneintranet/issues/2696>`_)

Technical:

- A status page has been added to help the administrator to inspect the health of the intid persistent utility
  (`Issue #2659 <https://github.com/quaive/ploneintranet/issues/2659>`_)


2.0.0a4 (2019-05-07)
--------------------

Changed:


- Remove unused classes WorkflowWorkspaceFolder and IWorkflowWorkspaceFolder
  (`Issue #2650 <https://github.com/quaive/ploneintranet/issues/2650>`_)


Fixed:


- Fix links to favicons (`Issue #2002
  <https://github.com/quaive/ploneintranet/issues/2002>`_)
- Removed an unnecessary reindex to speed up the preview generation. (`Issue
  #2635 <https://github.com/quaive/ploneintranet/issues/2635>`_)


Technical:


- The SeachableText contained in the portal_catalog will no longer index data not required
  (`Issue #1731 <https://github.com/quaive/ploneintranet/issues/1731>`_)
- Allow developers to use the black coding style with a configuration that is consistent with the
  current code style (`Issue #2549
  <https://github.com/quaive/ploneintranet/issues/2549>`_)
- Remove occurrences of the tiles syntax to prevent problems in sites that the use
  _vh_rewrites. (`Issue #2642
  <https://github.com/quaive/ploneintranet/issues/2642>`_)
- Ensure that a workgroup is always created with the "canonical" attribute set.
  (`Issue #2644 <https://github.com/quaive/ploneintranet/issues/2644>`_)


Updated:


- Upgrade collective.documentviewer to version 5.0.2 (`Issue #2166
  <https://github.com/quaive/ploneintranet/issues/2166>`_)


2.0.0a3 (2019-04-11)
--------------------

Changed:


- Improve the speed to display the news sections. Note that users that can see a section
  must be a direct member of the group that can view the section. (`Issue #2164
  <https://github.com/quaive/ploneintranet/issues/2164>`_)
- Calendar app: Events can now be attached to multiple calendars in the sidebar.
  Only deselecting all calendars hides the event. (`Issue #2618
  <https://github.com/quaive/ploneintranet/issues/2618>`_)
- Changed the default title of the intranet group to match the group id "All
  Intranet Users" (`Issue #2621
  <https://github.com/quaive/ploneintranet/issues/2621>`_)


Fixed:


- Content is addable again in barceloneta. This was broken due to a Plone bug. (`Issue #2620
  <https://github.com/quaive/ploneintranet/issues/2620>`_)
- When setting a security policy, only change the participant policy if needed. (`Issue #2628
  <https://github.com/quaive/ploneintranet/issues/2628>`_)


Technical:


- Do not depend on plone.app.ldap but of Products.PloneLDAP. Update
  collective.auditlog to 1.4.0a3. Provide patches for missing interfaces after
  the removal of plone.app.kss and plone.app.ldap. (`Issue #2620
  <https://github.com/quaive/ploneintranet/issues/2620>`_)


2.0.0a2 (2019-04-03)
--------------------

Fixed:


- When requesting access to a private workspace, the compose email window of
  the local mail client is opened (`Issue #2611
  <https://github.com/quaive/ploneintranet/issues/2611>`_)
- Speed up the news views (`Issue #2614
  <https://github.com/quaive/ploneintranet/issues/2614>`_)


Technical:


- Improve the performace of the local role adapter that grants the Reviewer role to owners
  (`Issue #2614 <https://github.com/quaive/ploneintranet/issues/2614>`_)
- Fix the migration of private workspaces to respect the old
  hide_private_nonmember_workspaces registry record (`Issue #2559
  <https://github.com/quaive/ploneintranet/issues/2559>`_)


2.0.0a1 (2019-03-28)
--------------------

Added:


- Added support for better, quicker and nicer preview images (`Issue #2241
  <https://github.com/quaive/ploneintranet/issues/2241>`_)
- Added task attachments (`Issue #2537
  <https://github.com/quaive/ploneintranet/issues/2537>`_)
- Added a maintenance view that allows the admin to regenerate the previews of recently modified
  documents (`Issue #2578
  <https://github.com/quaive/ploneintranet/issues/2578>`_)
- Date pickers now support the configured first day of the week (`Issue #2595
  <https://github.com/quaive/ploneintranet/issues/2595>`_)


Changed:


- Added an explanatory message if the activity stream is empty.
- Removed the extranet group, which was experimental and is no longer needed.
- Display the new-post-box tile only if we have the permission to add.
  (`Issue #1988
  <https://github.com/quaive/ploneintranet/issues/1988>`_)
- Provided a fix for the preview generation package to avoid a problem where some pages
  in the library were not visible due to a misbehaving external package.
  (`Issue #2438
  <https://github.com/quaive/ploneintranet/issues/2438>`_)
- The workspace task sidebar has been greatly extended to support nearly all functionality that
  is also available in the todo app
  (`Issue #2488 <https://github.com/quaive/ploneintranet/issues/2488>`_)
- We now have support for open workspaces. (`Issue #2559
  <https://github.com/quaive/ploneintranet/issues/2559>`_)
- The security sidebar of a workspace is now simpler and clearer (`Issue #2014
  <https://github.com/quaive/ploneintranet/issues/2014>`_)


Fixed:


- Fixes a problem where the workspace sidebar would not show when there was
  a document had no known type. (`Issue #2441
  <https://github.com/quaive/ploneintranet/issues/2441>`_)
- The document title is now visible when expanding the metadata bar (except
  when the space is occupied by the rich text formatting bar). (`Issue #2444
  <https://github.com/quaive/ploneintranet/issues/2444>`_)
- Library: Fixed a problem where Firefox would not download a file in the
  "Download a selection of content" feature.
  (`Issue #2550 <https://github.com/quaive/ploneintranet/issues/2550>`_)
- Fixed a problem in underlying Plone that would prevent the External Editor
  to function. (`Issue #2561
  <https://github.com/quaive/ploneintranet/issues/2561>`_)
- Made the display of documents on the user profile more stable (`Issue #2584
  <https://github.com/quaive/ploneintranet/issues/2584>`_)
- Improved the event edit form to properly display current values and not
  display any tabs if it is not possible to add calendars (`Issue #2588
  <https://github.com/quaive/ploneintranet/issues/2588>`_)
- Improve the configuration form of the news publisher (`Issue #2590
  <https://github.com/quaive/ploneintranet/issues/2590>`_)
- Remove the bookmark icon from the workspace tile if I don't have access
  to the workspace (`Issue #2603
  <https://github.com/quaive/ploneintranet/issues/2603>`_)


Technical:


- Technical (content creation): Pass descriptions when creating
  ObjectModifiedEvent. (`Issue #2533
  <https://github.com/quaive/ploneintranet/issues/2533>`_)
- Added an upgrade step to update the todo workflow (`Issue #2435
  <https://github.com/quaive/ploneintranet/issues/2435>`_)
- Remove the unused dependency from collective.instancebehavior (`Issue #1727
  <https://github.com/quaive/ploneintranet/issues/1727>`_)
- Remove workaround for #2404 (`Issue #1988
  <https://github.com/quaive/ploneintranet/issues/1988>`_)
- Remove unused imports (`Issue #2549
  <https://github.com/quaive/ploneintranet/issues/2549>`_)
- This release starts the Saturn release cycle. Some function and methods
  deprecated in Jupiter were removed. (`Issue #2555
  <https://github.com/quaive/ploneintranet/issues/2555>`_)


Updated:


- Upgrade to Plone 5.1.5 (`Issue #2166
  <https://github.com/quaive/ploneintranet/issues/2166>`_)
- Upgrade to collective.mustread 1.1.1
- Upgrade to quaive.app.taxonomy 1.3.1
- Upgrade to quaive.app.milestones 2.0.1
- Upgrade to quaive.app.onlyoffice 1.5.0

